====
xrpc
====

.. image:: https://img.shields.io/pypi/v/xrpc.svg
        :target: https://pypi.python.org/pypi/xrpc

.. image:: https://img.shields.io/travis/andreycizov/python-xrpc.svg
        :target: https://travis-ci.org/andreycizov/python-xrpc

.. image:: https://readthedocs.org/projects/xrpc/badge/?version=latest
        :target: https://xrpc.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/andreycizov/python-xrpc/shield.svg
        :target: https://pyup.io/repos/github/andreycizov/python-xrpc/
        :alt: Updates

.. image:: https://codecov.io/gh/andreycizov/python-xrpc/coverage.svg?branch=master
        :target: https://codecov.io/gh/andreycizov/python-xrpc/?branch=master

Motivation
----------


Includes
________

 - Automated python `typing` module deserialization of primitives
 - 3 modes of message passing
 - UDP-based protocols
 - creative logging customisation
 - easy daemon creations


Example
_______

see examples for now


.. code-block:: python

Author
------
Andrey Cizov (acizov@gmail.com), 2018